@@ -1,7 +1,11 @@
 from django.contrib.auth import authenticate, get_user_model
-from rest_framework import serializers
+from django.utils import six
+from django.utils.module_loading import import_string
+from rest_framework import exceptions, serializers
 from rest_framework.authtoken.models import Token
-from . import constants, utils
+
+from . import constants, utils, settings
+
 
 User = get_user_model()
 
@@ -20,7 +24,9 @@ class UserSerializer(serializers.ModelSerializer):
 
 
 class UserRegistrationSerializer(serializers.ModelSerializer):
-    password = serializers.CharField(style={'input_type': 'password'}, write_only=True)
+    password = serializers.CharField(style={'input_type': 'password'},
+                                     write_only=True,
+                                     validators=settings.get('PASSWORD_VALIDATORS'))
 
     class Meta:
         model = User
@@ -31,7 +37,11 @@ class UserRegistrationSerializer(serializers.ModelSerializer):
         )
 
     def create(self, validated_data):
-        return User.objects.create_user(**validated_data)
+        user = User.objects.create_user(**validated_data)
+        if settings.get('SEND_ACTIVATION_EMAIL'):
+            user.is_active = False
+            user.save(update_fields=['is_active'])
+        return user
 
 
 class LoginSerializer(serializers.Serializer):
@@ -66,7 +76,8 @@ class UidAndTokenSerializer(serializers.Serializer):
     token = serializers.CharField()
 
     default_error_messages = {
-        'invalid_token': constants.INVALID_TOKEN_ERROR
+        'invalid_token': constants.INVALID_TOKEN_ERROR,
+        'invalid_uid': constants.INVALID_UID_ERROR,
     }
 
     def validate_uid(self, value):
@@ -74,7 +85,7 @@ class UidAndTokenSerializer(serializers.Serializer):
             uid = utils.decode_uid(value)
             self.user = User.objects.get(pk=uid)
         except (User.DoesNotExist, ValueError, TypeError, OverflowError) as error:
-            raise serializers.ValidationError(error)
+            raise serializers.ValidationError(self.error_messages['invalid_uid'])
         return value
 
     def validate(self, attrs):
@@ -84,8 +95,21 @@ class UidAndTokenSerializer(serializers.Serializer):
         return attrs
 
 
+class ActivationSerializer(UidAndTokenSerializer):
+    default_error_messages = {
+        'stale_token': constants.STALE_TOKEN_ERROR,
+    }
+
+    def validate(self, attrs):
+        attrs = super(ActivationSerializer, self).validate(attrs)
+        if self.user.is_active:
+            raise exceptions.PermissionDenied(self.error_messages['stale_token'])
+        return attrs
+
+
 class PasswordSerializer(serializers.Serializer):
-    new_password = serializers.CharField(style={'input_type': 'password'})
+    new_password = serializers.CharField(style={'input_type': 'password'},
+                                         validators=settings.get('PASSWORD_VALIDATORS'))
 
 
 class PasswordRetypeSerializer(PasswordSerializer):
@@ -171,3 +195,25 @@ class TokenSerializer(serializers.ModelSerializer):
         fields = (
             'auth_token',
         )
+
+
+class SerializersManager(object):
+    def __init__(self, serializer_confs):
+        self.serializers = serializer_confs.copy()
+
+    def get(self, serializer_name):
+        try:
+            if isinstance(self.serializers[serializer_name], six.string_types):
+                self.serializers[serializer_name] = self.load_serializer(
+                    self.serializers[serializer_name])
+            return self.serializers[serializer_name]
+        except KeyError:
+            raise Exception("Try to use serializer name '%s' that is not one of: %s" % (
+                serializer_name,
+                tuple(settings.get('SERIALIZERS').keys())
+            ))
+
+    def load_serializer(self, serializer_class):
+        return import_string(serializer_class)
+
+serializers_manager = SerializersManager(settings.get('SERIALIZERS'))
