@@ -1,11 +1,13 @@
 from django.contrib.auth import get_user_model, user_logged_in, user_logged_out
+from django.contrib.auth.tokens import default_token_generator
 from rest_framework import generics, permissions, status, response, views
 from rest_framework.authtoken.models import Token
 from rest_framework.response import Response
 from rest_framework.reverse import reverse
-from django.contrib.auth.tokens import default_token_generator
+
 from . import serializers, settings, utils, signals
 
+
 User = get_user_model()
 
 
@@ -46,7 +48,7 @@ class RegistrationView(utils.SendEmailViewMixin, generics.CreateAPIView):
     """
     Use this endpoint to register new user.
     """
-    serializer_class = serializers.UserRegistrationSerializer
+    serializer_class = serializers.serializers_manager.get('user_registration')
     permission_classes = (
         permissions.AllowAny,
     )
@@ -70,7 +72,7 @@ class LoginView(utils.ActionViewMixin, generics.GenericAPIView):
     """
     Use this endpoint to obtain user authentication token.
     """
-    serializer_class = serializers.LoginSerializer
+    serializer_class = serializers.serializers_manager.get('login')
     permission_classes = (
         permissions.AllowAny,
     )
@@ -79,8 +81,9 @@ class LoginView(utils.ActionViewMixin, generics.GenericAPIView):
         user = serializer.user
         token, _ = Token.objects.get_or_create(user=user)
         user_logged_in.send(sender=user.__class__, request=self.request, user=user)
+        token_serializer_class = serializers.serializers_manager.get('token')
         return Response(
-            data=serializers.TokenSerializer(token).data,
+            data=token_serializer_class(token).data,
             status=status.HTTP_200_OK,
         )
 
@@ -96,14 +99,14 @@ class LogoutView(views.APIView):
     def post(self, request):
         Token.objects.filter(user=request.user).delete()
         user_logged_out.send(sender=request.user.__class__, request=request, user=request.user)
-        return response.Response(status=status.HTTP_200_OK)
+        return response.Response(status=status.HTTP_204_NO_CONTENT)
 
 
 class PasswordResetView(utils.ActionViewMixin, utils.SendEmailViewMixin, generics.GenericAPIView):
     """
     Use this endpoint to send email to user with password reset link.
     """
-    serializer_class = serializers.PasswordResetSerializer
+    serializer_class = serializers.serializers_manager.get('password_reset')
     permission_classes = (
         permissions.AllowAny,
     )
@@ -114,7 +117,7 @@ class PasswordResetView(utils.ActionViewMixin, utils.SendEmailViewMixin, generic
     def action(self, serializer):
         for user in self.get_users(serializer.data['email']):
             self.send_email(**self.get_send_email_kwargs(user))
-        return response.Response(status=status.HTTP_200_OK)
+        return response.Response(status=status.HTTP_204_NO_CONTENT)
 
     def get_users(self, email):
         active_users = User._default_manager.filter(
@@ -139,13 +142,13 @@ class SetPasswordView(utils.ActionViewMixin, generics.GenericAPIView):
 
     def get_serializer_class(self):
         if settings.get('SET_PASSWORD_RETYPE'):
-            return serializers.SetPasswordRetypeSerializer
-        return serializers.SetPasswordSerializer
+            return serializers.serializers_manager.get('set_password_retype')
+        return serializers.serializers_manager.get('set_password')
 
     def action(self, serializer):
         self.request.user.set_password(serializer.data['new_password'])
         self.request.user.save()
-        return response.Response(status=status.HTTP_200_OK)
+        return response.Response(status=status.HTTP_204_NO_CONTENT)
 
 
 class PasswordResetConfirmView(utils.ActionViewMixin, generics.GenericAPIView):
@@ -159,20 +162,20 @@ class PasswordResetConfirmView(utils.ActionViewMixin, generics.GenericAPIView):
 
     def get_serializer_class(self):
         if settings.get('PASSWORD_RESET_CONFIRM_RETYPE'):
-            return serializers.PasswordResetConfirmRetypeSerializer
-        return serializers.PasswordResetConfirmSerializer
+            return serializers.serializers_manager.get('password_reset_confirm_retype')
+        return serializers.serializers_manager.get('password_reset_confirm')
 
     def action(self, serializer):
         serializer.user.set_password(serializer.data['new_password'])
         serializer.user.save()
-        return response.Response(status=status.HTTP_200_OK)
+        return response.Response(status=status.HTTP_204_NO_CONTENT)
 
 
 class ActivationView(utils.ActionViewMixin, generics.GenericAPIView):
     """
     Use this endpoint to activate user account.
     """
-    serializer_class = serializers.UidAndTokenSerializer
+    serializer_class = serializers.serializers_manager.get('activation')
     permission_classes = (
         permissions.AllowAny,
     )
@@ -183,27 +186,26 @@ class ActivationView(utils.ActionViewMixin, generics.GenericAPIView):
         serializer.user.save()
         signals.user_activated.send(
             sender=self.__class__, user=serializer.user, request=self.request)
-        return Response(status=status.HTTP_200_OK)
+        return Response(status=status.HTTP_204_NO_CONTENT)
 
 
 class SetUsernameView(utils.ActionViewMixin, generics.GenericAPIView):
     """
     Use this endpoint to change user username.
     """
-    serializer_class = serializers.SetUsernameSerializer
     permission_classes = (
         permissions.IsAuthenticated,
     )
 
     def get_serializer_class(self):
         if settings.get('SET_USERNAME_RETYPE'):
-            return serializers.SetUsernameRetypeSerializer
-        return serializers.SetUsernameSerializer
+            return serializers.serializers_manager.get('set_username_retype')
+        return serializers.serializers_manager.get('set_username')
 
     def action(self, serializer):
         setattr(self.request.user, User.USERNAME_FIELD, serializer.data['new_' + User.USERNAME_FIELD])
         self.request.user.save()
-        return response.Response(status=status.HTTP_200_OK)
+        return response.Response(status=status.HTTP_204_NO_CONTENT)
 
 
 class UserView(generics.RetrieveUpdateAPIView):
@@ -211,7 +213,7 @@ class UserView(generics.RetrieveUpdateAPIView):
     Use this endpoint to retrieve/update user.
     """
     model = User
-    serializer_class = serializers.UserSerializer
+    serializer_class = serializers.serializers_manager.get('user')
     permission_classes = (
         permissions.IsAuthenticated,
     )
